diff src/normal.c @ 18775:5da1ad9165f0 v8.1.2377

patch 8.1.2377: GUI: when losing focus a pending operator is executed Commit: https://github.com/vim/vim/commit/fa5612c7d836eb789e0f8ff4b10461b8640a14b2 Author: Bram Moolenaar <Bram@vim.org> Date: Sun Dec 1 19:37:07 2019 +0100 patch 8.1.2377: GUI: when losing focus a pending operator is executed Problem: GUI: when losing focus a pending operator is executed. Solution: Do not execute an operator when getting K_IGNORE. (closes https://github.com/vim/vim/issues/5300)
author Bram Moolenaar <Bram@vim.org>
date Sun, 01 Dec 2019 19:45:03 +0100
parents bbea1f108187
children 7982f65d8f54
line wrap: on
line diff
--- a/src/normal.c
+++ b/src/normal.c
@@ -1099,9 +1099,10 @@ getcount:
 	old_mapped_len = typebuf_maplen();
 
     /*
      * If an operation is pending, handle it...
      */
-    do_pending_operator(&ca, old_col, FALSE);
+    if (ca.cmdchar != K_IGNORE)
+	do_pending_operator(&ca, old_col, FALSE);
 
     /*
      * Wait for a moment when a message is displayed that will be overwritten
@@ -1099,9 +1099,10 @@ getcount:
 
     /*
-     * If an operation is pending, handle it...
+     * If an operation is pending, handle it.  But not for K_IGNORE.
      */